@@ -22,6 +22,7 @@ OPTIONAL_SETTINGS = [
     ConfigVar("throw_errors", "APORIA_THROW_ERRORS", False, _str_to_bool),
     ConfigVar("debug", "APORIA_DEBUG", False, _str_to_bool),
     ConfigVar("http_timeout_seconds", "APORIA_HTTP_TIMEOUT_SECONDS", 30, int),
+    ConfigVar("verify_ssl", "APORIA_VERIFY_SSL", True, _str_to_bool),
 ]
 ALL_SETTINGS = [*REQUIRED_SETTINGS, *OPTIONAL_SETTINGS]
 
@@ -51,6 +52,7 @@ class Config:
         self.throw_errors = settings["throw_errors"]
         self.debug = settings["debug"]
         self.http_timeout_seconds = settings["http_timeout_seconds"]
+        self.verify_ssl = settings["verify_ssl"]
 
         # Constant values - we keep those here to make overriding them in the tests easier.
         # speed and our expected rate for inserting a prediction
