@@ -60,6 +60,7 @@ def init(
     throw_errors: Optional[bool] = None,
     debug: Optional[bool] = None,
     http_timeout_seconds: Optional[int] = None,
+    verify_ssl: bool = True,
 ):
     """Initialize the Aporia SDK.
 
@@ -101,6 +102,7 @@ def init(
             throw_errors=throw_errors,
             debug=debug,
             http_timeout_seconds=http_timeout_seconds,
+            verify_ssl=verify_ssl,
         )
 
         set_log_level(config.debug)
@@ -111,6 +113,7 @@ def init(
             host=config.host,
             port=config.port,
             default_timeout=config.http_timeout_seconds,
+            verify_ssl=verify_ssl,
         )
 
         init_context(http_client=http_client, event_loop=event_loop, config=config)
