@@ -1,6 +1,7 @@
 import asyncio
 from concurrent.futures import Future
 import logging
+import platform
 from threading import Thread
 from typing import Any, Coroutine
 
@@ -15,6 +16,9 @@ class EventLoop:
     def __init__(self):
         """Initializes an EventLoop instance."""
         logger.debug("Starting event loop in a worker thread.")
+        if platform.system() == "Windows":
+            policy = asyncio.WindowsSelectorEventLoopPolicy()
+            asyncio.set_event_loop_policy(policy)
         self.loop = asyncio.new_event_loop()
         self.loop_thread = Thread(target=self.run_loop, daemon=True)
 
