@@ -1,4 +1,4 @@
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 import numpy as np
 from pandas import DataFrame, Series
@@ -27,7 +27,7 @@ def calculate_dataframe_training_data(
         if field_name not in fields_schema:
             continue
 
-        training_data.append(
+        training_data.extend(
             calculate_training_data(
                 field_name=field_name,
                 field_data=field_data,
@@ -40,7 +40,7 @@ def calculate_dataframe_training_data(
 
 def calculate_training_data(
     field_name: str, field_data: Series, field_type: FieldType
-) -> FieldTrainingData:
+) -> List[FieldTrainingData]:
     """Calculates training data for a single field.
 
     Args:
@@ -51,21 +51,39 @@ def calculate_training_data(
     Returns:
         Field training data.
     """
-    # We currently don't support datetime, vector & text training data
+    # We currently don't support datetime, vector, text & dict training data
     if field_type in [FieldType.DATETIME, FieldType.VECTOR, FieldType.TEXT]:
-        return _calculate_training_data_without_histogram(
-            field_name=field_name, field_data=field_data
-        )
+        return [
+            _calculate_training_data_without_histogram(field_name=field_name, field_data=field_data)
+        ]
     elif field_type == FieldType.NUMERIC:
-        return _calculate_numeric_training_data(field_name=field_name, field_data=field_data)
+        return [_calculate_numeric_training_data(field_name=field_name, field_data=field_data)]
+    elif field_type == FieldType.DICT:
+        return _calculate_dict_training_data(field_name=field_name, field_data=field_data)
     elif field_type in [FieldType.BOOLEAN, FieldType.STRING, FieldType.CATEGORICAL]:
-        return _calculate_categorical_training_data(
-            field_name=field_name, field_data=field_data, field_type=field_type
-        )
+        return [
+            _calculate_categorical_training_data(
+                field_name=field_name, field_data=field_data, field_type=field_type
+            )
+        ]
 
     raise AporiaError("Unsupported field type {} of field {}".format(field_type.value, field_name))
 
 
+def _calculate_dict_training_data(field_name: str, field_data: Series) -> List[FieldTrainingData]:
+    # Each row in field_data is expected to be a dict: {"a": 0.5, "b": 0.2}
+    # By using .apply(Series), we can expand each key to a column in a dataframe
+    expanded_dict_data = field_data.apply(Series)
+
+    training_data = []
+    for key, key_data in expanded_dict_data.items():
+        training_data.append(
+            _calculate_numeric_training_data(field_name=field_name, key=key, field_data=key_data)
+        )
+
+    return training_data
+
+
 def _calculate_training_data_without_histogram(
     field_name: str, field_data: Series
 ) -> FieldTrainingData:
@@ -101,7 +119,9 @@ def _calculate_categorical_training_data(
     )
 
 
-def _calculate_numeric_training_data(field_name: str, field_data: Series) -> FieldTrainingData:
+def _calculate_numeric_training_data(
+    field_name: str, field_data: Series, key: Optional[str] = None
+) -> FieldTrainingData:
     # Cast everything to float and normalize null values (some operations don't work on pd.NA)
     field_data = field_data.fillna(np.nan).astype(float)  # type: ignore
 
@@ -112,6 +132,7 @@ def _calculate_numeric_training_data(field_name: str, field_data: Series) -> Fie
 
     return FieldTrainingData(
         field_name=field_name,
+        key=key,
         bins=bins.tolist(),
         counts=counts.tolist(),
         min=np.min(finite_values),
